==> libnb-platform-java_6.7.1.orig.tar.gz: libnb-platform-java-6.7.1/core.startup/test/unit/src/org/netbeans/core/startup/preferences/NbPreferencesTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.core.startup.preferences;

import java.util.prefs.Preferences;
import junit.framework.Test;
import junit.framework.TestResult;
import junit.framework.TestSuite;
import org.netbeans.junit.NbTestCase;

/**
 *
 * @author Radek Matous
 */
public class NbPreferencesTest extends NbTestCase {    
    public NbPreferencesTest(String testName) {
        super(testName);
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite();
        suite.addTestSuite(TestPreferences.class);
        suite.addTestSuite(TestFileStorage.class);
        suite.addTestSuite(TestPropertiesStorage.class);
        suite.addTestSuite(TestNbPreferencesFactory.class);
        
        return suite;
    }
    
    public static class TestBasicSetup extends NbTestCase {
        public TestBasicSetup(String testName) {
            super(testName);                        
        }
        
        public void run(final TestResult result) {
            //just do registration before code NbTestCase
            NbPreferencesFactory.doRegistration();       
            Preferences.userRoot();                        
            super.run(result);
        }
        
        protected void tearDown() throws Exception {
            super.tearDown();
            /*Logger logger = Logger.getAnonymousLogger();
            logger.log(Level.INFO  ,getName()+ "->" + Statistics.FLUSH.toString());//NOI18N
            logger.log(Level.INFO,getName()+ "->" + Statistics.LOAD.toString());//NOI18N
            logger.log(Level.INFO,getName()+ "->" + Statistics.REMOVE_NODE.toString());//NOI18N
            logger.log(Level.INFO,getName()+ "->" + Statistics.CHILDREN_NAMES.toString());//NOI18N
             **/
        }
        
        protected void setUp() throws Exception {            
            super.setUp();                        
            Statistics.CHILDREN_NAMES.reset();
            Statistics.FLUSH.reset();
            Statistics.LOAD.reset();
            Statistics.REMOVE_NODE.reset();
        }           
    }
}

==> libnb-platform-java_6.8.orig.tar.gz: libnb-platform-java-6.8/core.startup/test/unit/src/org/netbeans/core/startup/preferences/NbPreferencesTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.core.startup.preferences;

import java.util.prefs.Preferences;
import junit.framework.Test;
import junit.framework.TestResult;
import junit.framework.TestSuite;
import org.netbeans.junit.NbTestCase;

/**
 *
 * @author Radek Matous
 */
public class NbPreferencesTest extends NbTestCase {    
    public NbPreferencesTest(String testName) {
        super(testName);
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite();
        suite.addTestSuite(TestPreferences.class);
        suite.addTestSuite(TestFileStorage.class);
        suite.addTestSuite(TestPropertiesStorage.class);
        suite.addTestSuite(TestNbPreferencesFactory.class);
        
        return suite;
    }
    
    public static class TestBasicSetup extends NbTestCase {
        public TestBasicSetup(String testName) {
            super(testName);                        
        }
        
        public @Override void run(final TestResult result) {
            //just do registration before code NbTestCase
            NbPreferencesFactory.doRegistration();       
            Preferences.userRoot();                        
            super.run(result);
        }
        
        protected @Override void tearDown() throws Exception {
            super.tearDown();
            /*Logger logger = Logger.getAnonymousLogger();
            logger.log(Level.INFO  ,getName()+ "->" + Statistics.FLUSH.toString());//NOI18N
            logger.log(Level.INFO,getName()+ "->" + Statistics.LOAD.toString());//NOI18N
            logger.log(Level.INFO,getName()+ "->" + Statistics.REMOVE_NODE.toString());//NOI18N
            logger.log(Level.INFO,getName()+ "->" + Statistics.CHILDREN_NAMES.toString());//NOI18N
             **/
        }
        
        protected @Override void setUp() throws Exception {
            super.setUp();                        
            Statistics.CHILDREN_NAMES.reset();
            Statistics.FLUSH.reset();
            Statistics.LOAD.reset();
            Statistics.REMOVE_NODE.reset();
        }           
    }
}
